@@ -45,7 +45,7 @@ class QDF:
                  align: bool = True, ):
         assert isinstance(data, (pl.LazyFrame, pl.DataFrame)), "data must be a polars DataFrame or LazyFrame"
         data = data.lazy()
-        data = data.cast({pl.Decimal: pl.Float32})
+        data = data.cast({pl.Decimal: pl.Float64})# .cast({pl.Float32: pl.Float64})
         self.data = data.collect()
         self.index = index
         self.dims = [self.data[name].drop_nulls().n_unique() for name in index]
