@@ -203,4 +203,7 @@ def itd_zscore(expr: pl.Expr, windows):
     return (expr - itd_mean(expr, windows))/itd_std(expr, windows)
 
 def itd_norm(expr: pl.Expr, windows):
-    return (expr - itd_mid(expr, windows))/itd_mad(expr, windows)
\ No newline at end of file
+    return (expr - itd_mid(expr, windows))/itd_mad(expr, windows)
+
+def itd_fill_forward(expr: pl.Expr):
+    return expr.fill_null(strategy="forward").over(**over)
\ No newline at end of file
